**| [Overview](#overview) | [Download](#download) | [Instalation](#installation) | [License](#license) | [Contact](#contact) |**

# Symupy

[![Documentation Status](https://readthedocs.org/projects/symupy/badge/?version=stable)](https://symupy.readthedocs.io/en/stable/?badge=stable) ![PyPI](https://img.shields.io/pypi/v/symupy) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/symupy) 

A Python API to control and interact with SymuVia. Please find more information in the [documentation](https://symupy.readthedocs.io/en/latest/)

## Overview 

## Download 

You can download the latest version in this [link](https://github.com/symuvia/symupy/archive/master.zip) or clone this repository at

```
git clone https://github.com/symuvia/symupy.git
```

## Installation 

There are two possibilities to install this package. 

1. To get the last stable release. You can install this package via `pip`: 

  ```
  pip install symupy
  ```

2. To retrieve the `edge` version with latest changes. You can install from the source code: 

   ```
   pip install https://github.com/symuvia/symupy/archive/master.zip
   ```


## Usage 
